2.0.0 (2024-08-30)
------------------

- Allow executing checks multiple times with different parameters; `ALIVE_CHECKS` should now be a list of tuples (setting it to a dictionary results in a deprecation warning).


1.2.2 (2024-08-14)
------------------

- Add GitHub Action for running tests against supported versions
- Release from GitHub Actions


1.2.1 (2021-07-23)
------------------

* Update PyPI metadata


1.2.0 (2021-07-23)
------------------

* Updated test matrix. Python 2 no longer "officially" supported.
* Prevent Traceback in middleware if URLs are not setup


1.1.0 (2019-11-06)
------------------

* Added `healthcheck` management command
* Added optional `check_migrations` healthcheck


1.0.1 (2018-09-10)
------------------

* Documentation improvements
* Python 3.7 support


1.0.0 (2018-08-21)
------------------

* Initial release
